package javax.swing.plaf.basic;

import java.lang.reflect.InvocationTargetException;
import javax.swing.Action;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.ActionMap;
import javax.swing.JComponent;
import javax.swing.plaf.ActionMapUIResource;

class LazyActionMap extends ActionMapUIResource
{
    private transient Object _loader;
    
    static void installLazyActionMap(JComponent component, Class clazz, String s) {
        ActionMap actionMap = (ActionMap)UIManager.get(s);
        if (actionMap == null) {
            actionMap = new LazyActionMap(clazz);
            UIManager.getLookAndFeelDefaults().put(s, actionMap);
        }
        SwingUtilities.replaceUIActionMap(component, actionMap);
    }
    
    static ActionMap getActionMap(Class clazz, String s) {
        ActionMap value = (ActionMap)UIManager.get(s);
        if (value == null) {
            value = new LazyActionMap(clazz);
            UIManager.getLookAndFeelDefaults().put(s, value);
            return value;
        }
        return value;
    }
    
    private LazyActionMap(Class loader) {
        this._loader = loader;
    }
    
    public void put(Action action) {
        this.put(action.getValue("Name"), action);
    }
    
    @Override
    public void put(Object key, Action action) {
        this.loadIfNecessary();
        super.put(key, action);
    }
    
    @Override
    public Action get(Object key) {
        this.loadIfNecessary();
        return super.get(key);
    }
    
    @Override
    public void remove(Object key) {
        this.loadIfNecessary();
        super.remove(key);
    }
    
    @Override
    public void clear() {
        this.loadIfNecessary();
        super.clear();
    }
    
    @Override
    public Object[] keys() {
        this.loadIfNecessary();
        return super.keys();
    }
    
    @Override
    public int size() {
        this.loadIfNecessary();
        return super.size();
    }
    
    @Override
    public Object[] allKeys() {
        this.loadIfNecessary();
        return super.allKeys();
    }
    
    @Override
    public void setParent(ActionMap parent) {
        this.loadIfNecessary();
        super.setParent(parent);
    }
    
    private void loadIfNecessary() {
        if (this._loader != null) {
            Object loader = this._loader;
            this._loader = null;
            Class<Object> clazz = (Class)loader;
            try {
                clazz.getDeclaredMethod("loadActionMap", new Class[] { LazyActionMap.class }).invoke(clazz, new Object[] { this });
            }
            catch (NoSuchMethodException ex) {
                assert false : "LazyActionMap unable to load actions " + clazz;
            }
            catch (IllegalAccessException obj) {
                assert false : "LazyActionMap unable to load actions " + obj;
            }
            catch (InvocationTargetException obj2) {
                assert false : "LazyActionMap unable to load actions " + obj2;
            }
            catch (IllegalArgumentException obj3) {
                assert false : "LazyActionMap unable to load actions " + obj3;
            }
        }
    }
}
